/*
 * Copyright (c) 2006-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: MemoNode.java,v 1.6 2007/05/19 02:45:22 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.graph.system;

import org.xmlpull.infoset.XmlElement;

import edu.indiana.extreme.xbaya.graph.Graph;
import edu.indiana.extreme.xbaya.graph.GraphException;
import edu.indiana.extreme.xbaya.graph.GraphSchema;
import edu.indiana.extreme.xbaya.graph.gui.NodeGUI;
import edu.indiana.extreme.xbaya.graph.system.gui.MemoNodeGUI;

/**
 * @author Satoshi Shirasuna
 */
public class MemoNode extends SystemNode {

    private MemoNodeGUI gui;

    private String memo;

    /**
     * Constructs a ParameterNode.
     * 
     * @param graph
     * 
     */
    public MemoNode(Graph graph) {
        super(graph);
        this.memo = "Double click here\nto take memo.";
    }

    /**
     * Constructs a MemoNode.
     * 
     * @param nodeElement
     * @throws GraphException
     */
    public MemoNode(XmlElement nodeElement) throws GraphException {
        super(nodeElement);
    }

    /**
     * Returns the memo.
     * 
     * @return The memo
     */
    public String getMemo() {
        return this.memo;
    }

    /**
     * Sets memo.
     * 
     * @param memo
     *            The memo to set.
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    /**
     * @see edu.indiana.extreme.xbaya.graph.Node#getGUI()
     */
    public NodeGUI getGUI() {
        if (this.gui == null) {
            this.gui = new MemoNodeGUI(this);
        }
        return this.gui;
    }

    @Override
    protected XmlElement toXML() {
        XmlElement nodeElement = super.toXML();
        nodeElement.setAttributeValue(GraphSchema.NS,
                GraphSchema.NODE_TYPE_ATTRIBUTE, GraphSchema.NODE_TYPE_MEMO);
        XmlElement memoElement = nodeElement.addElement(GraphSchema.NS,
                GraphSchema.NODE_MEMO_TAG);
        memoElement.addChild(this.memo);
        return nodeElement;
    }

    /**
     * @see edu.indiana.extreme.xbaya.graph.impl.NodeImpl#parse(org.xmlpull.infoset.XmlElement)
     */
    @Override
    protected void parse(XmlElement nodeElement) throws GraphException {
        super.parse(nodeElement);
        XmlElement memoElement = nodeElement.element(GraphSchema.NODE_MEMO_TAG);
        this.memo = memoElement.requiredText();
    }

}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
